        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <br>1,2,3,5,6,9,10,16,19,20,21,22,24,32,33,35,38,39,40,41,44,46,47,48';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 16 <strong>control</strong><br>0,4,7,11,14,15,17,25,26,27,28,29,31,37,42,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,12,13,18,23,30,34,36,43,45,49';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <br>1,2,3,5,6,9,10,16,19,20,21,22,24,32,33,35,38,39,40,41,44,46,47,48';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 16 <strong>control</strong><br>0,4,7,11,14,15,17,25,26,27,28,29,31,37,42,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,12,13,18,23,30,34,36,43,45,49';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <br>1,2,3,5,6,9,10,16,19,20,21,22,24,32,33,35,38,39,40,41,44,46,47,48';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 16 <strong>control</strong><br>0,4,7,11,14,15,17,25,26,27,28,29,31,37,42,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,12,13,18,23,30,34,36,43,45,49';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <br>1,2,3,5,6,9,10,16,19,20,21,22,24,32,33,35,38,39,40,41,44,46,47,48';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 16 <strong>control</strong><br>0,4,7,11,14,15,17,25,26,27,28,29,31,37,42,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,12,13,18,23,30,34,36,43,45,49';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <br>1,2,3,5,6,9,10,16,19,20,21,22,24,32,33,35,38,39,40,41,44,46,47,48';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 16 <strong>control</strong><br>0,4,7,11,14,15,17,25,26,27,28,29,31,37,42,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,12,13,18,23,30,34,36,43,45,49';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <br>1,2,3,5,6,9,10,16,19,20,21,22,24,32,33,35,38,39,40,41,44,46,47,48';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 16 <strong>control</strong><br>0,4,7,11,14,15,17,25,26,27,28,29,31,37,42,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260815 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <br>8,12,13,18,23,30,34,36,43,45,49';}
}
